# geomt


[![image](https://img.shields.io/pypi/v/geomt.svg)](https://pypi.python.org/pypi/geomt)
[![image](https://img.shields.io/conda/vn/conda-forge/geomt.svg)](https://anaconda.org/conda-forge/geomt)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT License
-   Documentation: https://amccorketutoring.github.io/geomt
    

## Features

-   TODO
